@@ -109,6 +109,7 @@ __all__ = (
     "VeevaSourcePropertiesTypeDef",
     "ZendeskConnectorProfileCredentialsTypeDef",
     "ZendeskConnectorProfilePropertiesTypeDef",
+    "ZendeskDestinationPropertiesTypeDef",
     "ZendeskMetadataTypeDef",
     "ZendeskSourcePropertiesTypeDef",
     "ConnectorProfileConfigTypeDef",
@@ -600,6 +601,7 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
         "Upsolver": "UpsolverDestinationPropertiesTypeDef",
         "Honeycode": "HoneycodeDestinationPropertiesTypeDef",
         "CustomerProfiles": "CustomerProfilesDestinationPropertiesTypeDef",
+        "Zendesk": "ZendeskDestinationPropertiesTypeDef",
     },
     total=False,
 )
@@ -1366,6 +1368,26 @@ ZendeskConnectorProfilePropertiesTypeDef = TypedDict(
     "ZendeskConnectorProfilePropertiesTypeDef", {"instanceUrl": str}
 )
 
+_RequiredZendeskDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredZendeskDestinationPropertiesTypeDef", {"object": str}
+)
+_OptionalZendeskDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalZendeskDestinationPropertiesTypeDef",
+    {
+        "idFieldNames": List[str],
+        "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
+        "writeOperationType": Literal["INSERT", "UPSERT", "UPDATE"],
+    },
+    total=False,
+)
+
+
+class ZendeskDestinationPropertiesTypeDef(
+    _RequiredZendeskDestinationPropertiesTypeDef, _OptionalZendeskDestinationPropertiesTypeDef
+):
+    pass
+
+
 ZendeskMetadataTypeDef = TypedDict(
     "ZendeskMetadataTypeDef", {"oAuthScopes": List[str]}, total=False
 )
